@@ -2,11 +2,12 @@
 from pydantic import Field, validator, root_validator, constr
 from typing import Union
 
-from ._base import NamedEnergyBaseModel
+from ._base import IDdEnergyBaseModel
+from .schedule import ScheduleRuleset, ScheduleFixedInterval
 from ..altnumber import Autocalculate
 
 
-class PeopleAbridged(NamedEnergyBaseModel):
+class PeopleAbridged(IDdEnergyBaseModel):
 
     type: constr(regex='^PeopleAbridged$') = 'PeopleAbridged'
 
@@ -20,7 +21,7 @@ class PeopleAbridged(NamedEnergyBaseModel):
         ...,
         min_length=1,
         max_length=100,
-        description='Name of a schedule for the occupancy over the course of the '
+        description='Identifier of a schedule for the occupancy over the course of the '
             'year. The type of this schedule should be Fractional and the fractional '
             'values will get multiplied by the people_per_area to yield a complete '
             'occupancy profile.'
@@ -30,7 +31,7 @@ class PeopleAbridged(NamedEnergyBaseModel):
         ...,
         min_length=1,
         max_length=100,
-        description='Name of a schedule for the activity of the occupants over the '
+        description='Identifier of a schedule for the activity of the occupants over the '
             'course of the year. The type of this schedule should be Power and the '
             'values of the schedule equal to the number of Watts given off by an '
             'individual person in the room.'
@@ -51,9 +52,9 @@ class PeopleAbridged(NamedEnergyBaseModel):
         description='Number for the latent fraction of heat gain due to people or '
             'an Autocalculate object.'
     )
-    
+
     @root_validator
-    def check_sum_fractions(cls, values): 
+    def check_sum_fractions(cls, values):
         "Ensure sum is less than 1."
         rad = values.get('radiant_fraction')
         latent = values.get('latent_fraction')
@@ -71,7 +72,28 @@ class PeopleAbridged(NamedEnergyBaseModel):
                 ]
 
 
-class LightingAbridged(NamedEnergyBaseModel):
+class People(PeopleAbridged):
+
+    type: constr(regex='^People$') = 'People'
+
+    occupancy_schedule:  Union[ScheduleRuleset, ScheduleFixedInterval] = Field(
+        ...,
+        description='A schedule for the occupancy over the course of the '
+            'year. The type of this schedule should be Fractional and the fractional '
+            'values will get multiplied by the people_per_area to yield a complete '
+            'occupancy profile.'
+    )
+
+    activity_schedule: Union[ScheduleRuleset, ScheduleFixedInterval] = Field(
+        ...,
+        description='A schedule for the activity of the occupants over the '
+            'course of the year. The type of this schedule should be Power and the '
+            'values of the schedule equal to the number of Watts given off by an '
+            'individual person in the room.'
+    )
+
+
+class LightingAbridged(IDdEnergyBaseModel):
 
     type: constr(regex='^LightingAbridged$') = 'LightingAbridged'
 
@@ -85,7 +107,7 @@ class LightingAbridged(NamedEnergyBaseModel):
         ...,
         min_length=1,
         max_length=100,
-        description='Name of the schedule for the use of lights over the course of '
+        description='Identifier of the schedule for the use of lights over the course of '
             'the year. The type of this schedule should be Fractional and the '
             'fractional values will get multiplied by the watts_per_area to yield a '
             'complete lighting profile.'
@@ -116,7 +138,7 @@ class LightingAbridged(NamedEnergyBaseModel):
     )
 
     @root_validator
-    def check_sum_fractions(cls, values): 
+    def check_sum_fractions(cls, values):
         "Ensure sum is less than 1."
         return_air = values.get('return_air_fraction')
         vis = values.get('visible_fraction')
@@ -126,7 +148,20 @@ class LightingAbridged(NamedEnergyBaseModel):
         return values
 
 
-class _EquipmentBase(NamedEnergyBaseModel):
+class Lighting(LightingAbridged):
+
+    type: constr(regex='^Lighting$') = 'Lighting'
+
+    schedule: Union[ScheduleRuleset, ScheduleFixedInterval] = Field(
+        ...,
+        description='The schedule for the use of lights over the course of '
+            'the year. The type of this schedule should be Fractional and the '
+            'fractional values will get multiplied by the watts_per_area to yield a '
+            'complete lighting profile.'
+    )
+
+
+class _EquipmentBase(IDdEnergyBaseModel):
 
     watts_per_area: float = Field(
         ...,
@@ -138,7 +173,7 @@ class _EquipmentBase(NamedEnergyBaseModel):
         ...,
         min_length=1,
         max_length=100,
-        description='Name of the schedule for the use of equipment over the course '
+        description='Identifier of the schedule for the use of equipment over the course '
             'of the year. The type of this schedule should be Fractional and the '
             'fractional values will get multiplied by the watts_per_area to yield '
             'a complete equipment profile.'
@@ -156,7 +191,7 @@ class _EquipmentBase(NamedEnergyBaseModel):
         0,
         ge=0,
         le=1,
-        description='Number for the amount of latent heat given off by electric' 
+        description='Number for the amount of latent heat given off by electric'
         'equipment. Default value is 0.'
 
     )
@@ -170,7 +205,7 @@ class _EquipmentBase(NamedEnergyBaseModel):
     )
 
     @root_validator
-    def check_sum_fractions(cls, values): 
+    def check_sum_fractions(cls, values):
         "Ensure sum is less than 1."
         rad = values.get('radiant_fraction')
         latent = values.get('latent_fraction')
@@ -179,17 +214,44 @@ class _EquipmentBase(NamedEnergyBaseModel):
             'Sum of radiant, latent, and lost fractions cannot be greater than 1.'
         return values
 
+
 class ElectricEquipmentAbridged(_EquipmentBase):
 
     type: constr(regex='^ElectricEquipmentAbridged$') = 'ElectricEquipmentAbridged'
 
 
+class ElectricEquipment(ElectricEquipmentAbridged):
+
+    type: constr(regex='^ElectricEquipment$') = 'ElectricEquipment'
+
+    schedule: Union[ScheduleRuleset, ScheduleFixedInterval] = Field(
+        ...,
+        description='The schedule for the use of equipment over the course '
+            'of the year. The type of this schedule should be Fractional and the '
+            'fractional values will get multiplied by the watts_per_area to yield '
+            'a complete equipment profile.'
+    )
+
+
 class GasEquipmentAbridged(_EquipmentBase):
 
     type: constr(regex='^GasEquipmentAbridged$') = 'GasEquipmentAbridged'
 
 
-class InfiltrationAbridged(NamedEnergyBaseModel):
+class GasEquipment(GasEquipmentAbridged):
+
+    type: constr(regex='^GasEquipment$') = 'GasEquipment'
+
+    schedule: Union[ScheduleRuleset, ScheduleFixedInterval] = Field(
+        ...,
+        description='The schedule for the use of equipment over the course '
+            'of the year. The type of this schedule should be Fractional and the '
+            'fractional values will get multiplied by the watts_per_area to yield '
+            'a complete equipment profile.'
+    )
+
+
+class InfiltrationAbridged(IDdEnergyBaseModel):
 
     type: constr(regex='^InfiltrationAbridged$') = 'InfiltrationAbridged'
 
@@ -203,7 +265,7 @@ class InfiltrationAbridged(NamedEnergyBaseModel):
         ...,
         min_length=1,
         max_length=100,
-        description='Name of the schedule for the infiltration over the course of '
+        description='Identifier of the schedule for the infiltration over the course of '
             'the year. The type of this schedule should be Fractional and the '
             'fractional values will get multiplied by the flow_per_exterior_area '
             'to yield a complete infiltration profile.'
@@ -225,7 +287,20 @@ class InfiltrationAbridged(NamedEnergyBaseModel):
     )
 
 
-class VentilationAbridged(NamedEnergyBaseModel):
+class Infiltration(InfiltrationAbridged):
+
+    type: constr(regex='^Infiltration$') = 'Infiltration'
+
+    schedule: Union[ScheduleRuleset, ScheduleFixedInterval] = Field(
+        ...,
+        description='The schedule for the infiltration over the course of '
+            'the year. The type of this schedule should be Fractional and the '
+            'fractional values will get multiplied by the flow_per_exterior_area '
+            'to yield a complete infiltration profile.'
+    )
+
+
+class VentilationAbridged(IDdEnergyBaseModel):
 
     type: constr(regex='^VentilationAbridged$') = 'VentilationAbridged'
 
@@ -261,14 +336,29 @@ class VentilationAbridged(NamedEnergyBaseModel):
         default=None,
         min_length=1,
         max_length=100,
-        description='Name of the schedule for the ventilation over the course of '
+        description='Identifier of the schedule for the ventilation over the course of '
             'the year. The type of this schedule should be Fractional and the '
             'fractional values will get multiplied by the total design flow rate '
             '(determined from the sum of the other 4 fields) to yield a complete '
             'ventilation profile.'
     )
 
-class SetpointAbridged(NamedEnergyBaseModel):
+
+class Ventilation(VentilationAbridged):
+
+    type: constr(regex='^Ventilation$') = 'Ventilation'
+
+    schedule: Union[ScheduleRuleset, ScheduleFixedInterval] = Field(
+        default=None,
+        description='Schedule for the ventilation over the course of '
+            'the year. The type of this schedule should be Fractional and the '
+            'fractional values will get multiplied by the total design flow rate '
+            '(determined from the sum of the other 4 fields) to yield a complete '
+            'ventilation profile.'
+    )
+
+
+class SetpointAbridged(IDdEnergyBaseModel):
     """Used to specify information about the setpoint schedule."""
 
     type: constr(regex='^SetpointAbridged$') = 'SetpointAbridged'
@@ -277,7 +367,7 @@ class SetpointAbridged(NamedEnergyBaseModel):
         ...,
         min_length=1,
         max_length=100,
-        description='Name of the schedule for the cooling setpoint. The values in '
+        description='Identifier of the schedule for the cooling setpoint. The values in '
             'this schedule should be temperature in [C].'
     )
 
@@ -285,7 +375,7 @@ class SetpointAbridged(NamedEnergyBaseModel):
         ...,
         min_length=1,
         max_length=100,
-        description='Name of the schedule for the heating setpoint. The values in '
+        description='Identifier of the schedule for the heating setpoint. The values in '
             'this schedule should be temperature in [C].'
     )
 
@@ -293,20 +383,20 @@ class SetpointAbridged(NamedEnergyBaseModel):
         default=None,
         min_length=1,
         max_length=100,
-        description='Name of the schedule for the humidification setpoint. The values '
-            'in this schedule should be in [%].'
+        description='Identifier of the schedule for the humidification setpoint. '
+            'The values in this schedule should be in [%].'
     )
 
     dehumidifying_schedule: str = Field(
         default=None,
         min_length=1,
         max_length=100,
-        description='Name of the schedule for the dehumidification setpoint. The values '
-            'in this schedule should be in [%].'
+        description='Identifier of the schedule for the dehumidification setpoint. '
+            'The values in this schedule should be in [%].'
     )
 
     @root_validator
-    def check_both_himd_sch(cls, values): 
+    def check_both_himd_sch(cls, values):
         "Ensure that the other humidity schedule is included when one is."
         humid = values.get('humidifying_schedule')
         dehumid = values.get('dehumidifying_schedule')
@@ -319,6 +409,36 @@ class SetpointAbridged(NamedEnergyBaseModel):
         return values
 
 
+class Setpoint(SetpointAbridged):
+    """Used to specify information about the setpoint schedule."""
+
+    type: constr(regex='^Setpoint$') = 'Setpoint'
+
+    cooling_schedule: Union[ScheduleRuleset, ScheduleFixedInterval] = Field(
+        ...,
+        description='Schedule for the cooling setpoint. The values in '
+            'this schedule should be temperature in [C].'
+    )
+
+    heating_schedule: Union[ScheduleRuleset, ScheduleFixedInterval] = Field(
+        ...,
+        description='Schedule for the heating setpoint. The values in '
+            'this schedule should be temperature in [C].'
+    )
+
+    humidifying_schedule: Union[ScheduleRuleset, ScheduleFixedInterval] = Field(
+        default=None,
+        description='Schedule for the humidification setpoint. The values '
+            'in this schedule should be in [%].'
+    )
+
+    dehumidifying_schedule: Union[ScheduleRuleset, ScheduleFixedInterval] = Field(
+        default=None,
+        description='Schedule for the dehumidification setpoint. The values '
+            'in this schedule should be in [%].'
+    )
+
+
 if __name__ == '__main__':
     print(PeopleAbridged.schema_json(indent=2))
     print(LightingAbridged.schema_json(indent=2))
